"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchAndStoreRules = void 0;
const axios_1 = __importDefault(require("axios"));
const fs_1 = __importDefault(require("fs"));
const jsdom_1 = require("jsdom");
const constants_1 = require("./constants");
async function fetchAndStoreRules() {
    const response = await axios_1.default.get('https://typescript-eslint.io/rules/#extension-rules');
    const html = response.data;
    const dom = new jsdom_1.JSDOM(html);
    const supportedRulesTable = dom.window.document.querySelector('h2#supported-rules ~ table tbody');
    const extensionRulesTable = dom.window.document.querySelector('h2#extension-rules ~ table tbody');
    if (!supportedRulesTable || !extensionRulesTable) {
        throw new Error(`could not fetch rules`);
    }
    const allRules = [...supportedRulesTable.children, ...extensionRulesTable.children];
    const rulesRequiringTypeInfo = [];
    for (const tr of allRules) {
        const ruleRequiresTypeInfo = tr.querySelector('td[title="requires type information"]');
        if (ruleRequiresTypeInfo) {
            const ruleAnchor = tr.querySelector('td:first-child a');
            if (!ruleAnchor) {
                throw new Error(`found a rule but could not extract rule anchor`);
            }
            const nameOfRule = ruleAnchor.textContent;
            rulesRequiringTypeInfo.push(nameOfRule);
        }
    }
    await fs_1.default.promises.writeFile(constants_1.constants.RULES_PATH, JSON.stringify(rulesRequiringTypeInfo), {
        encoding: 'utf8',
    });
}
exports.fetchAndStoreRules = fetchAndStoreRules;
//# sourceMappingURL=fetch-and-store-rules.js.map